.. _user-guide-index:

.. toctree::
    :maxdepth: 2
    :caption: Introduction to FLUXUS
    :hidden:

    introduction_to_fluxus/building_a_flow


User Guide
==========

This section provides guidance for FLUXUS users, with more content to be added in the
future.

- **Introduction to FLUXUS**:
  Overview of core concepts and mechanics of using FLUXUS


Contributing to Our User Guide
------------------------------

We are committed to continuously improving our User Guide, ensuring it meets the needs
of our users and accurately reflects the breadth and depth of use cases for FLUXUS.

To this end, we enthusiastically encourage contributions from our community.
Whether you've identified an opportunity for enhancement, noticed a crucial piece
missing, or have an addition that could benefit others, we invite you to share your
expertise.

Should you come across any content gaps or areas for significant improvement, please do
not hesitate to open an issue on our `issue tracker <TBD>`_.
Your contributions help us make our User Guide a more valuable resource for everyone.

Before submitting contributions to the User Guide, be sure review our
:ref:`Contributor Guide <contributor-guide-index>`.
